@@ -20,6 +20,9 @@
 #include <QtPositioning/qgeosatelliteinfosource.h>
 #include <QtPositioning/qgeoshape.h>
 #include <QtPositioning/qnmeapositioninfosource.h>
+#include <QtPositioning/qnmeasatelliteinfosource.h>
+
+QT_BEGIN_NAMESPACE
 class QGeoAddress;
 class QGeoAreaMonitorInfo;
 class QGeoCircle;
@@ -28,6 +31,7 @@ class QGeoPath;
 class QGeoPolygon;
 class QGeoPositionInfoSourceFactory;
 class QGeoRectangle;
+QT_END_NAMESPACE
 
 // Type indices
 enum [[deprecated]] : int {
@@ -61,7 +65,10 @@ enum [[deprecated]] : int {
     SBK_QGEOSHAPE_IDX                                        = 52,
     SBK_QNMEAPOSITIONINFOSOURCE_UPDATEMODE_IDX               = 58,
     SBK_QNMEAPOSITIONINFOSOURCE_IDX                          = 56,
-    SBK_QTPOSITIONING_IDX_COUNT                              = 60,
+    SBK_QNMEASATELLITEINFOSOURCE_UPDATEMODE_IDX              = 64,
+    SBK_QNMEASATELLITEINFOSOURCE_SATELLITEINFOPARSESTATUS_IDX = 62,
+    SBK_QNMEASATELLITEINFOSOURCE_IDX                         = 60,
+    SBK_QTPOSITIONING_IDX_COUNT                              = 66,
 };
 
 // Type indices
@@ -96,7 +103,10 @@ enum : int {
     SBK_QGeoShape_IDX                                        = 26,
     SBK_QNmeaPositionInfoSource_UpdateMode_IDX               = 29,
     SBK_QNmeaPositionInfoSource_IDX                          = 28,
-    SBK_QtPositioning_IDX_COUNT                              = 30,
+    SBK_QNmeaSatelliteInfoSource_UpdateMode_IDX              = 32,
+    SBK_QNmeaSatelliteInfoSource_SatelliteInfoParseStatus_IDX = 31,
+    SBK_QNmeaSatelliteInfoSource_IDX                         = 30,
+    SBK_QtPositioning_IDX_COUNT                              = 33,
 };
 
 // This variable stores all Python types exported by this module.
@@ -137,6 +147,9 @@ enum : int {
 };
 // Macros for type check
 
+// Protected enum surrogates
+enum PySide6_QtPositioning_QNmeaSatelliteInfoSource_SatelliteInfoParseStatus_Surrogate {};
+
 QT_WARNING_PUSH
 QT_WARNING_DISABLE_DEPRECATED
 namespace Shiboken
@@ -173,6 +186,9 @@ template<> inline PyTypeObject *SbkType< ::QGeoShape::ShapeType >() { return Shi
 template<> inline PyTypeObject *SbkType< ::QGeoShape >() { return Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoShape_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QNmeaPositionInfoSource::UpdateMode >() { return Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QNmeaPositionInfoSource_UpdateMode_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QNmeaPositionInfoSource >() { return Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QNmeaPositionInfoSource_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QNmeaSatelliteInfoSource::UpdateMode >() { return Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QNmeaSatelliteInfoSource_UpdateMode_IDX]); }
+template<> inline PyTypeObject *SbkType< ::PySide6_QtPositioning_QNmeaSatelliteInfoSource_SatelliteInfoParseStatus_Surrogate >() { return Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QNmeaSatelliteInfoSource_SatelliteInfoParseStatus_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QNmeaSatelliteInfoSource >() { return Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QNmeaSatelliteInfoSource_IDX]); }
 
 } // namespace Shiboken
 
